import { Component, h } from '@stencil/core';
import * as wjCore from "@grapecity/wijmo";
import * as wjGrid from '@grapecity/wijmo.grid';
import * as wjDetail from '@grapecity/wijmo.grid.detail';

@Component({
  tag: 'app-home',
  styleUrl: 'app-home.css',
})
export class AppHome {
  grid: wjGrid.FlexGrid;
  dp: wjDetail.FlexGridDetailProvider;

  componentDidLoad() {
    const view = new wjCore.CollectionView(this.getData(5));
    this.grid = new wjGrid.FlexGrid('#theGrid', {
      autoGenerateColumns: false,
      columns: [
        { header: 'ID', binding: 'id', width: 40, align: 'center'},
        { header: 'Country', binding: 'country', width: '*'}
      ],
      itemsSource: view
    });

    this.dp = new wjDetail.FlexGridDetailProvider(this.grid, {
      createDetailCell: (row: wjGrid.Row) => {
        let item = row.dataItem.items;
        const cell = wjCore.createElement('<div></div>');
        let g = new wjGrid.FlexGrid(cell, {
          autoGenerateColumns: false,
          columns: [
            { header: 'Sales', binding: 'sales', width: '*', format: 'c2'},
            { header: 'Downloads', binding: 'downloads', width: '*', format: 'd'},
            { header: 'Active', binding: 'active', width: '*'}
          ],
          itemsSource: item
        });
        return cell;
      }
    })
  }

  getData(count) {
    var data = [],
      countries = 'US,Germany,UK,Japan,Italy,Greece'.split(',');
    for (var i = 0; i < count; i++) {
      data.push({
        id: i,
        country: countries[Math.floor(Math.random() * countries.length)],
        items: this.getChildData(5),
      });
    }
    return data;
  }

  getChildData(count) {
    var data = [];
    for (var i = 0; i < count; i++) {
      data.push({
        active: i % 5 != 0,
        downloads: Math.round(Math.random() * 200000),
        sales: Math.random() * 100000,
      });
    }
    return data;
  }

  render() {
    return [
      <ion-header>
        <ion-toolbar color="primary">
          <ion-title>Home</ion-title>
        </ion-toolbar>
      </ion-header>,

      <ion-content class="ion-padding">
        <div id="theGrid" />
      </ion-content>,
    ];
  }
}
